==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/LastMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastMonthExpressionDescription } from "./LastMonthExpressionDescription";
/**
 * @hidden
 */
export let LastMonthExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LastMonthExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LastMonthExpressionDescriptionMetadata.a == null) {
                LastMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LastMonthExpressionDescriptionMetadata.c(LastMonthExpressionDescriptionMetadata.a);
            }
            if (a.k(LastMonthExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ab(LastMonthExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            LastMonthExpressionDescriptionMetadata.b(a);
            a.ad("LastMonthExpression", () => new LastMonthExpressionDescription());
            a.ac("LastMonthExpression", LastMonthExpressionDescriptionMetadata.a);
        }
    }
    LastMonthExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LastMonthExpressionDescriptionMetadata, 'LastMonthExpressionDescriptionMetadata');
    LastMonthExpressionDescriptionMetadata.a = null;
    return LastMonthExpressionDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/LastMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastMonthExpressionDescription } from "./LastMonthExpressionDescription";
/**
 * @hidden
 */
export let LastMonthExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class LastMonthExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (LastMonthExpressionDescriptionMetadata.a == null) {
                LastMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LastMonthExpressionDescriptionMetadata.c(LastMonthExpressionDescriptionMetadata.a);
            }
            if (a.k(LastMonthExpressionDescriptionMetadata.a)) {
                return;
            }
            a.ac(LastMonthExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            LastMonthExpressionDescriptionMetadata.b(a);
            a.ae("LastMonthExpression", () => new LastMonthExpressionDescription());
            a.ad("LastMonthExpression", LastMonthExpressionDescriptionMetadata.a);
        }
    }
    LastMonthExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(LastMonthExpressionDescriptionMetadata, 'LastMonthExpressionDescriptionMetadata');
    LastMonthExpressionDescriptionMetadata.a = null;
    return LastMonthExpressionDescriptionMetadata;
})();
